@@ -56,9 +56,7 @@ prefix=/usr
 pnoslash=`echo $prefix | sed -e 's#^/##'`
 sysconfdir=/etc
 snoslash=`echo $sysconfdir | sed -e 's#^/##'`
-MY_CC="gcc-2"
-MY_CXX="g++-2"
-MY_CFLAGS="-O2"
+MY_CFLAGS=
 MY_LDFLAGS=
 
 mkdirs() {
@@ -77,17 +75,16 @@ prep() {
 conf() {
   (cd ${objdir} && \
   CFLAGS="${MY_CFLAGS}" LDFLAGS="${MY_LDFLAGS}" \
-  CC="${MY_CC}" CXX="${MY_CXX}" \
   ../dist/configure --target=${target} \
   --prefix=${prefix} \
   --exec-prefix=${prefix} --sysconfdir=${sysconfdir} \
   --bindir=${prefix}/bin --libdir=${prefix}/lib \
   --includedir=${prefix}/include/db${VERMAJ}.${VERMIN} \
-  --datadir=${prefix}/share \
+  --datadir=${prefix}/share --mandir=${prefix}/share/man \
+  --infodir=${prefix}/share/info \
   --libexecdir='${sbindir}' --localstatedir=/var \
   --program-transform-name="s,^db_,db${VERMAJ}.${VERMIN}_," \
-  --enable-posixmutexes --enable-dynamic --enable-cxx \
-  --enable-compat185 --disable-test
+  --enable-cxx --enable-compat185 --disable-test 
 )
 }
 build() {
@@ -104,26 +101,26 @@ clean() {
 }
 install() {
   (cd ${objdir} && \
-  make DESTDIR=${instdir} install
-  if [ -f ${instdir}${prefix}/info/dir ] ; then \
-    rm ${instdir}${prefix}/info/dir ; \
+  make install DESTDIR=${instdir} 
+  if [ -f ${instdir}${prefix}/share/info/dir ] ; then \
+    rm ${instdir}${prefix}/share/info/dir ; \
   fi && \
-  if [ -d ${instdir}${prefix}/doc/${PKG}-${VER} ]; then \
-    rm -rf ${instdir}${prefix}/doc/${PKG}-${VER} 
+  if [ -d ${instdir}${prefix}/share/doc/${PKG}-${VER} ]; then \
+    rm -rf ${instdir}${prefix}/share/doc/${PKG}-${VER} 
   fi && \
-  if [ -d ${instdir}${prefix}/doc/${PKG3}-${VER} ]; then \
-    rm -rf ${instdir}${prefix}/doc/${PKG3}-${VER} 
+  if [ -d ${instdir}${prefix}/share/doc/${PKG3}-${VER} ]; then \
+    rm -rf ${instdir}${prefix}/share/doc/${PKG3}-${VER} 
   fi && \
-  mkdir -p ${instdir}${prefix}/doc/${PKG}-${VER} && \
-  mkdir -p ${instdir}${prefix}/doc/${PKG3}-${VER} && \
-  for f in ${instdir}${prefix}/doc/db/* ; do
-    mv $f ${instdir}${prefix}/doc/${PKG}-${VER}/
+  mkdir -p ${instdir}${prefix}/share/doc/${PKG}-${VER} && \
+  mkdir -p ${instdir}${prefix}/share/doc/${PKG3}-${VER} && \
+  for f in ${instdir}${prefix}/share/doc/db/* ; do
+    mv $f ${instdir}${prefix}/share/doc/${PKG}-${VER}/
   done && \
-  rmdir ${instdir}${prefix}/doc/db && \
-  mv ${instdir}${prefix}/doc/${PKG}-${VER}/utility \
-     ${instdir}${prefix}/doc/${PKG3}-${VER}/ && \
-  if [ ! -d ${instdir}${prefix}/doc/Cygwin ]; then \
-    mkdir -p ${instdir}${prefix}/doc/Cygwin ; \
+  rmdir ${instdir}${prefix}/share/doc/db && \
+  mv ${instdir}${prefix}/share/doc/${PKG}-${VER}/utility \
+     ${instdir}${prefix}/share/doc/${PKG3}-${VER}/ && \
+  if [ ! -d ${instdir}${prefix}/share/doc/Cygwin ]; then \
+    mkdir -p ${instdir}${prefix}/share/doc/Cygwin ; \
   fi && \
   if [ ! -d ${instdir}${sysconfdir}/postinstall ]; then \
     mkdir -p ${instdir}${sysconfdir}/postinstall ; \
@@ -136,18 +133,20 @@ install() {
   done && \
   if [ ! "x$templist" = "x" ]; then \
     /usr/bin/install -m 644 $templist \
-         ${instdir}${prefix}/doc/${PKG}-${VER} ;
+         ${instdir}${prefix}/share/doc/${PKG}-${VER} ;
     /usr/bin/install -m 644 $templist \
-         ${instdir}${prefix}/doc/${PKG3}-${VER} ;
+         ${instdir}${prefix}/share/doc/${PKG3}-${VER} ;
   fi && \
   cat ${srcdir}/CYGWIN-PATCHES/${PKG}.frag \
     ${srcdir}/CYGWIN-PATCHES/README.frag > \
-         ${instdir}${prefix}/doc/Cygwin/${PKG}-${VER}.README && \
+         ${instdir}${prefix}/share/doc/Cygwin/${PKG}-${VER}.README && \
   cat ${srcdir}/CYGWIN-PATCHES/${PKG3}.frag \
     ${srcdir}/CYGWIN-PATCHES/README.frag > \
-         ${instdir}${prefix}/doc/Cygwin/${PKG3}-${VER}.README && \
+         ${instdir}${prefix}/share/doc/Cygwin/${PKG3}-${VER}.README && \
   /usr/bin/install -m 755 ${srcdir}/CYGWIN-PATCHES/postinstall.sh \
-    ${instdir}${sysconfdir}/postinstall/libdb${VERMAJ}.${VERMIN}-devel.sh ;
+    ${instdir}${sysconfdir}/postinstall/libdb${VERMAJ}.${VERMIN}-devel.sh ; && \
+  for i in archive deadlock load recover upgrade checkpoint dump printlog \
+    stat verify ; do mv ${instdir}${prefix}/bin/db_${i}.exe ${instdir}${prefix}/bin/db${VERMAJ}.${VERMIN}_${i}.exe ; done ;
 )
 }
 strip() {
@@ -156,25 +155,26 @@ strip() {
   find . -name "*.exe" | xargs strip > /dev/null 2>&1 )
 }
 pkg() {
-  (cd ${instdir} && \
+  (cd ${instdir} && find . -type f | xargs touch && \
   tar cvjf ${bin_pkg} --exclude="${pnoslash}/bin" \
+    --exclude="${snoslash}/etc" \
     --exclude="${pnoslash}/include" \
     --exclude="${pnoslash}/lib" \
     --exclude="${snoslash}/postinstall" \
-    --exclude="${pnoslash}/doc/${PKG3}*" \
-    --exclude="${pnoslash}/doc/Cygwin/${PKG3}*" \
+    --exclude="${pnoslash}/share/doc/${PKG3}*" \
+    --exclude="${pnoslash}/share/doc/Cygwin/${PKG3}*" \
 	 * ;
   tar cvjf ${bin_pkg2} ${pnoslash}/bin/*.dll ;
   tar cvjf ${bin_pkg3} ${pnoslash}/bin/*.exe \
     ${pnoslash}/include ${pnoslash}/lib ${snoslash}/postinstall \
-    ${pnoslash}/doc/${PKG3}* ${pnoslash}/doc/Cygwin/${PKG3}* )
+    ${pnoslash}/share/doc/${PKG3}* ${pnoslash}/share/doc/Cygwin/${PKG3}* )
 }
 mkpatch() {
   (cd ${srcdir} && \
   tar xvzf ${src_orig_pkg} ;\
   mv ${PKG}-${VER} ../${PKG}-${VER}-orig && \
   cd ${topdir} && \
-  diff -urN -x '.build' -x '.inst' -x '.sinst' \
+  diff -urN -x '.build' -x '.inst' -x '.sinst' -x 'autom4te.cache' -x 'configure.lineno' \
     ${PKG}-${VER}-orig ${PKG}-${VER} > \
     ${srcinstdir}/${src_patch_name} ; \
   rm -rf ${PKG}-${VER}-orig )
@@ -207,6 +207,9 @@ case $1 in
   all) prep && conf && build && install && \
      strip && pkg && spkg && finish ; \
 	  STATUS=$? ;;
+  cbisps) conf && build && install && \
+     strip && pkg && spkg ; \
+	  STATUS=$? ;;
   *) echo "Error: bad arguments" ; exit 1 ;;
 esac
 exit ${STATUS}
